using System;
using System.Data;
using System.Collections;
using System.Data.SqlClient;

using NUnit.Framework;

using Lattice.Mapping;
using Lattice.Common;

namespace Lattice.DataMapper.UnitTest
{
	/// <summary>
	/// Summary description for testPersist.
	/// </summary>
	[TestFixture]
	public class testPersist
	{
		IDataMapper mapper = null;

		[SetUp]
		public void SetUp()
		{
			mapper = DataManager.Instance.Create();
		}
        
        [Test]
        public void testBulkInsert()
        {
            int count = 100;
            DateTime start = DateTime.Now;
            for (int i=0; i<count; i++)
            {
                Order order = new Order();
                order.CustomerID = "ALFKI";
                order.EmployeeID = 7;
                order.OrderDate = DateTime.Now;

                mapper.Create(order);
            }
            mapper.Persist();

            DateTime end = DateTime.Now;
            TimeSpan diff = end - start;
            double seconds = diff.TotalSeconds;
            Console.WriteLine(count + " records have been inserted");
            Console.WriteLine("Start Time: " + start.ToLongTimeString());
            Console.WriteLine("End Time: " + end.ToLongTimeString());
            Console.WriteLine("Time Span: " + seconds + " seconds.");

            Console.WriteLine("---------------------------------------");
        }
        [Test]
        public void testNullable()
        {
            Order order = new Order();
            order.CustomerID = "ALFKI";

            mapper.Create(order);
            mapper.Persist();
        }
		[Test]
		public void testInsert()
		{
			Customer customer = new Customer();
			customer.CustomerID = "AAAAA";
			customer.CompanyName = "Lattice Business Software";
			
			mapper.Create( customer );
			mapper.Persist();
		}

		[Test]
		public void testUpdate()
		{
			Customer customer = new Customer();
			customer.CustomerID = "AAAAA";
			customer.CompanyName = "Just for Fun, Inc.";

			mapper.Update( customer );
			mapper.Persist();
		}

		[Test]
		public void testDelete()
		{
			mapper.Delete( typeof(Customer), "AAAAA" );
			mapper.Persist();
		}

		[Test]
		public void testBatch()
		{
			Customer customer = new Customer();
			customer.CustomerID = "AAAAA";
			customer.CompanyName = "Lattice Business Software";
			
			mapper.Create( customer );

			customer.CompanyName = "Lattice Software";

			mapper.Update( customer );

			mapper.Delete( typeof(Customer), "AAAAA" );

			mapper.Persist();
		}

		[Test]
		public void testBatchDueTime()
		{
			Customer customer = new Customer();
			customer.CustomerID = "AAAAA";
			customer.CompanyName = "Lattice Business Software";
			
			mapper.Create( customer );

			customer.CompanyName = "Just For Fun, Inc.";

			mapper.Update( customer );

			mapper.Delete( typeof(Customer), "AAAAA" );

			mapper.Persist( new TimeSpan(0,0,30) );
		}

	}
}
